**Example 1: 绑定主机账号私钥**

绑定主机账号私钥

Input: 

```
tccli dasb BindDeviceAccountPrivateKey --cli-unfold-argument  \
    --PrivateKey xx \
    --Id 1 \
    --PrivateKeyPassword xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

